/*
 * Copyright (c) 2021 Contributors to the Eclipse Foundation.
 * Copyright (c) 1997, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package ee.jakarta.tck.faces.test.javaee8.commandScript;

import static java.lang.System.getProperty;
import static org.jboss.shrinkwrap.api.ShrinkWrap.create;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.net.URL;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.test.api.ArquillianResource;
import org.jboss.shrinkwrap.api.importer.ZipImporter;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import com.gargoylesoftware.htmlunit.WebClient;
import com.gargoylesoftware.htmlunit.html.HtmlPage;

import jakarta.faces.component.html.HtmlCommandScript;

@RunWith(Arquillian.class)
public class Spec613IT {

    @ArquillianResource
    private URL webUrl;
    private WebClient webClient;

    @Deployment(testable = false)
    public static WebArchive createDeployment() {
        return create(ZipImporter.class, getProperty("finalName") + ".war")
                .importFrom(new File("target/" + getProperty("finalName") + ".war"))
                .as(WebArchive.class);
    }

    @Before
    public void setUp() {
        webClient = new WebClient();
        webClient.getOptions().setJavaScriptEnabled(true);
        webClient.setJavaScriptTimeout(120000);
    }

    /**
     * @see HtmlCommandScript
     * @see https://github.com/jakartaee/faces/issues/613
     */
    @Test
    public void test() throws Exception {
        webClient.setIncorrectnessListener((o,i) -> {});

        testCommandScript();
    }

    public void testCommandScript() throws Exception {
        HtmlPage page = webClient.getPage(webUrl + "spec613.xhtml");
        webClient.waitForBackgroundJavaScript(60000);
        assertTrue(page.getWebResponse().getContentAsString().contains(">var foo=function(o){"));
        assertTrue(page.getHtmlElementById("result").asNormalizedText().equals("foo"));

        page.executeJavaScript("bar()");
        webClient.waitForBackgroundJavaScript(60000);
        assertTrue(page.getHtmlElementById("result").asNormalizedText().equals("bar"));
    }

    @After
    public void tearDown() {
        webClient.close();
    }

}
